%% Fig02_TC_outerwind_series
% power series solutions to outer wind profiles from Emanuel, 2004
%
% 
% Script for Figure 2 of Cronin, 2023, GRL - "An analytic model for
% Tropical cyclone outer winds"
% 
% Author: Tim Cronin, MIT; twcronin@mit.edu
%
% Functions used: 
%   E04_AM_ratio_matrix
%   gcfsavepdf

%------------- BEGIN CODE --------------

% variable      value           units               description
% -------------------------------------------------------------------------
r =             [0:0.0001:1];   % -                 normalized radius r/r_0
gamma =    [0.1 0.3 1 3 10 30 100 300 1000];% -     nondimensional control parameter
nterms =        [2:1:100];
G = zeros(length(r),length(gamma),length(nterms));% output array of ratio of tangential wind to AMC limit     
G_true = zeros(length(r),length(gamma)); %          output array with 100 terms in series
G_bessel = zeros(length(r),length(gamma)); %        bessel function approximation to solution near r=1
G_emp   = zeros(length(r),length(gamma)); %         empirical approximation to solution
G_test  = zeros(length(r),length(gamma)); %         approx to solution??
G_exp   = zeros(length(r),length(gamma)); %         exponential approximation to solution near r=1
G_sqrt  = zeros(length(r),length(gamma)); %         approximation to solution from E04, eqn. 39 
max_error = zeros(length(gamma),length(nterms)); %  maximum relative error at any radius
max_err20 = zeros(length(gamma),length(nterms)); %  maximum relative error outside r/r_0 = 0.2

%tic;
G_true = E04_AM_ratio_matrix(r,gamma,100);
for j=1:length(nterms)
    G(:,:,j) = E04_AM_ratio_matrix(r,gamma,nterms(j));
    max_error(:,j) = max(abs(G(:,:,j)-G_true(:,:))./G_true,[],1);
    max_err20(:,j) = max(abs(G(:,:,j)-G_true(:,:)).*repmat((r>=0.2)',1,length(gamma))./G_true,[],1);
end

%% make figure of G(r) for varied gamma and relative error at different series truncation lengths
set(0,'defaultaxesfontsize',14,'defaultaxesfontweight','normal',...
                'defaultlinelinewidth',1,'DefaultAxesFontName','Helvetica')

linecolors = parula(length(gamma)+1);

figure('Position',[50 50 900 400]);
subplot(1,3,1:2)
hold on;
set(gca,'Fontsize',14)
for i=1:length(gamma)
    plot(r,G_true(:,i),'color',linecolors(i,:))
    leg_str(i) = {['\gamma = ' num2str(gamma(i))]};
end
xlabel('Radius, r/r_0')
ylabel({'Ratio of wind speed to AM-conserving limit'; 'G(r) = V/V_{AMC}'})
box on;

% plot the Bessel function ratio approximation
for i=1:length(gamma)
    G_bessel(:,i) = 1./sqrt(gamma(i).*(1-r)).*besseli(1,2*sqrt(gamma(i)*(1-r)))./besseli(0,2*sqrt(gamma(i)*(1-r)));
    plot(r,G_bessel(:,i), '--', 'color',linecolors(i,:))
    
    % various test approximations...
    G_sqrt(:,i) = sqrt(2/gamma(i)).*sqrt(r./(1-r.^2));
    %plot(r,G_sqrt(:,i), ':', 'color',linecolors(i,:))
    
    G_emp(:,i) = 1./(1+gamma(i).*(1-r)).^(1/2+1/6.*(1-r));
    plot(r, G_emp(:,i), ':', 'color',linecolors(i,:))
    % -- this one is nice and super simple
    
    G_test(:,i) = sqrt(1./(2*(1+gamma(i)*(1-r)).^(3/2)) + 2*r.*(sqrt(1+gamma(i)*(1-r))-1)./(gamma(i).*(1-r.^2).*(1+gamma(i)*(1-r)).^(1/2)));
    %plot(r, G_test(:,i), ':', 'color',linecolors(i,:))
    
end
ylim([0 1])

legend(leg_str,'Location','EastOutside')
title('a) G(r) at different \gamma','Fontweight','normal')

subplot(1,3,3)
hold on;
set(gca,'Fontsize',14)
for i=1:length(gamma)
    plot(nterms,max_error(i,:),'color',linecolors(i,:))
    %plot(nterms,max_err20(i,:),'--','color',linecolors(i,:))
end
xlabel('Number of terms in series')
ylabel('Maximum relative error in series solution')
box on;
ylim([1e-10 1])
xlim([0 100])
set(gca,'Yscale','log')
title('b) Error scaling in series solution','Fontweight','normal')

gcfsavepdf('/Users/timothycronin/Dropbox/ConfsTalksPubs/Cronin2023_TC-OuterWindModel/Fig02_TC_outerwind_series.pdf')


