%% FigS1_benchmark_C23_CLE15
% 
% code to compare and make a few plots of merged V(r) for my method and for
% CLE15 (numerical) outer wind solution
%
% Script for Figure S1 of Cronin, 2023, GRL - "An analytic model for
% Tropical cyclone outer winds"
% 
% Author: Tim Cronin, MIT; twcronin@mit.edu
%
% Functions used: 
%   ER11E04_nondim_rmaxinput -- from Chavas et al (2015) solutions
%         -- see https://purr.purdue.edu/publications/4066/1, or doi:10.4231/CZ4P-D448
%   TC23_windprofile
%   gcfsavepdf

%------------- BEGIN CODE --------------

clear all;
close all;

% *** EDIT PATH HERE that contains this code ***
basedir = '/Users/timothycronin/Dropbox/ConfsTalksPubs/Cronin2023_TC-OuterWindModel/';
% *** EDIT PATH HERE TO Chavas, Lin, Emanuel (2015) code ***
addpath(genpath([basedir 'CLE15_code/mfiles/']));

nstorms     = 100;
Vmax        = 17+60*rand(nstorms,1);
rmax        = 1000*(15+100*rand(nstorms,1));
fcor        = 5e-5 + 7.5e-5*rand(nstorms,1);
C_d         = 0.0015;
w_cool      = 0.001 + 0.004*rand(nstorms,1);

n_plot      = 5;
i_plot      = randi(nstorms,n_plot,1); %indices of storms to plot
rr_CLE15    = NaN(10000,nstorms);
VV_CLE15    = NaN(10000,nstorms);

figure;

% Chavas, Lin, Emanuel 2015 code
tic;
for i=1:nstorms
    [rrCLE15,VVCLE15,r0CLE15,rmergeCLE15,rrfracr0CLE15,MMfracM0CLE15,rmaxr0CLE15,MmM0CLE15,rmerger0CLE15,MmergeM0CLE15] = ...
        ER11E04_nondim_rmaxinput(Vmax(i),rmax(i),fcor(i),0,C_d,w_cool(i),0,1,0,0);
    
    rr_CLE15(1:length(rrCLE15),i) = rrCLE15;
    VV_CLE15(1:length(VVCLE15),i) = VVCLE15;
end
time_CLE15 = toc;

% my new code: run all at once
tic;
%[rrTC23,VVTC23,r0TC23,rmergeTC23,rrfracr0TC23,MMfracM0TC23,rmaxr0TC23,MmM0TC23,rmerger0TC23,MmergeM0TC23] = ...
%    TC23_windprofile(Vmax,rmax,fcor,C_d,w_cool); 
[rrTC23,VVTC23,r0TC23,rmergeTC23] = TC23_windprofile(Vmax,rmax,fcor,C_d,w_cool);
time_TC23 = toc;

time_ratio = time_TC23/time_CLE15

%% make a figure comparing cases
figure('Position',[50 50 600 600]);
subplot(2,1,1)
colors = lines(i_plot);
hold on;
set(gca,'Fontsize',16)
n_plotted = 0;
rmaxplot = 0;
for i=1:nstorms
    if ismember(i,i_plot)
        n_plotted = n_plotted + 1;
        plot(0.001*rr_CLE15(:,i), VV_CLE15(:,i), '-', 'color',0.5+0.5*colors(n_plotted, :), 'LineWidth',2)
        plot(0.001*rrTC23(i,:), VVTC23(i,:), '--', 'color',0.25*colors(n_plotted, :))
        rmaxplot1 = max(0.001*max(rr_CLE15(:,i)), 0.001*max(rrTC23(i,:)));
        rmaxplot = max(rmaxplot,rmaxplot1);
    end
end

box on;
xlabel('Radius, r (km)')
ylabel('Tangential wind, V (m/s)') 
ylim([0 80])
xlim([0 500*ceil(rmaxplot/500)]);

legend(['CLE15 code: ' num2str(time_CLE15/nstorms,2) ' s/profile'], ['This study: ' num2str(time_TC23/nstorms,2) ' s/profile']);

subplot(2,1,2)
hold on; 
set(gca,'Fontsize',16)
n_plotted = 0;
rmax_TC23 = zeros(nstorms,1);
rmax_CLE15 = zeros(nstorms,1);
for i=1:nstorms
    if ismember(i,i_plot)
        n_plotted = n_plotted + 1;
        rp = max(max(rr_CLE15(:,i)),max(rrTC23(i,:)));
        rarr = (1:1:2000)/2000.*rp;
        vTC23 = interp1(rrTC23(i,:), VVTC23(i,:), rarr);
        inds = ~isnan(rr_CLE15(:,i));
        vCLE15 = interp1(rr_CLE15(inds,i), VV_CLE15(inds,i), rarr);
        plot(0.001*rarr, vTC23-vCLE15, '-', 'color', colors(n_plotted, :),'LineWidth',1)
        rms_error(n_plotted) = sqrt(nanmean((vTC23-vCLE15).^2));
    end
    if ~isnan(rrTC23(i,1))
        ind = VVTC23(i,:)==max(VVTC23(i,:),[],2);
        rmax_TC23(i) = rrTC23(i,ind);
        ind = VV_CLE15(:,i)==max(VV_CLE15(:,i),[],1);
        rmax_CLE15(i) = rr_CLE15(ind,i);
    end
end
box on;
xlabel('Radius, r (km)')
ylabel('Difference in V (m/s)')
xlim([0 500*ceil(rmaxplot/500)]);
line([0 500*ceil(rmaxplot/500)], [0 0], 'LineStyle','--','Color','k');

gcfsavepdf('/Users/timothycronin/Dropbox/ConfsTalksPubs/Cronin2023_TC-OuterWindModel/FigS1_benchmarking_CLE15-defaults.pdf')


